import requests
from typing import List

class Tesco:
    def __init__(self, key:str) -> None:
        self.key = key
    
    def grocery_search(self, query:str, offset:int=0, limit:int=10) -> List:
        params:dict = {
            "query": query,
            "offset": offset,
            "limit": limit           
        }
        headers:dict = {
            "Ocp-Apim-Subscription-Key": self.key
        }
        base:str = "https://dev.tescolabs.com/grocery/products/"
        
        r = requests.get(base, params=params, headers=headers)
        
        return r.json()["uk"]["ghs"]["products"]["results"]
    
    def product_data(self, gtin:str="", tpnb:str="", tpnc:str="", catid:str="") -> List:
        params:dict = {
            "gtin": gtin,
            "tpnb": tpnb,
            "tpnc": tpnc,          
            "catid": catid
        }
        cleaned_params:dict = {k: v for k, v in params.items() if v is not ""}
        headers:dict = {
            "Ocp-Apim-Subscription-Key": self.key
        }
        base:str = "https://dev.tescolabs.com/product/"
        
        r = requests.get(base, params=cleaned_params, headers=headers)
        
        return r.json()["products"]


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tesco']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.23.0,<3.0.0']

setup_kwargs = {
    'name': 'tesco',
    'version': '0.7.0',
    'description': '',
    'long_description': '# Tesco\n\n A Python wrapper for the Tesco API\n\n Install: `pip install tesco`',
    'author': 'Miles Budden',
    'author_email': 'miles@budden.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pbexe/tesco',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
